@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- *  $Id: tar-ext.c,v 1.11.2.6 2003/05/13 11:25:53 makeinu Exp $
+ *  $Id: tar-ext.c,v 1.11.2.7 2003/06/11 06:41:17 makeinu Exp $
  */
 
 #include <sys/types.h>
@@ -317,7 +317,7 @@ process_line (char *line, gpointer data)
    }
    if (fdata) {
       if (fields[1])
-         fdata->link = g_strdup (fields[1]);
+         image_info_set_link (fdata, fields[1]);
       comm->file_list = g_list_prepend (comm->file_list, fdata);
    }
 
