@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_view_xine.c,v 1.1.2.6 2003/06/03 16:14:58 makeinu Exp $
+ * $Id: image_view_xine.c,v 1.1.2.8 2003/06/11 09:56:28 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +29,7 @@
 
 #include <stdlib.h>
 
-#include "image_view.h"
+#include "gimv_image_view.h"
 #include "gimv_xine.h"
 #include "gimv_plugin.h"
 #include "gtkutils.h"
@@ -41,52 +41,52 @@
 static gint         idle_branched                    (gpointer   data);
 static void         cb_need_next_mrl                 (GimvXine  *gtx,
                                                       gchar    **next_mrl_ret,
-                                                      ImageView *iv);
+                                                      GimvImageView *iv);
 static void         cb_branched                      (GimvXine  *gtx,
-                                                      ImageView *iv);
+                                                      GimvImageView *iv);
 #endif /* GIMV_XINE_XINE1_API_IS_ENABLED */
 static void         cb_playback_finished             (GimvXine  *gtx,
-                                                      ImageView *iv);
+                                                      GimvImageView *iv);
 static void         cb_destroy                       (GtkWidget *widget,
-                                                      ImageView *iv);
+                                                      GimvImageView *iv);
 
 /* other private fiunctions */
 static gboolean     timeout_movie_status_listener    (gpointer   data);
 static gint         timeout_create_thumbnail         (gpointer   data);
-static void         install_movie_listener           (ImageView *iv);
-static void         remove_movie_listener            (ImageView *iv);
-static void         install_create_thumbnail_timer   (ImageView *iv);
-static void         remove_create_thumbnail_timer    (ImageView *iv);
-static void         imageview_xine_real_play         (ImageView *iv,
+static void         install_movie_listener           (GimvImageView *iv);
+static void         remove_movie_listener            (GimvImageView *iv);
+static void         install_create_thumbnail_timer   (GimvImageView *iv);
+static void         remove_create_thumbnail_timer    (GimvImageView *iv);
+static void         imageview_xine_real_play         (GimvImageView *iv,
                                                       guint      pos);
-static gboolean     imageview_xine_is_playing        (ImageView *iv);
+static gboolean     imageview_xine_is_playing        (GimvImageView *iv);
 
 /* vertual functions */
-static gboolean     imageview_xine_is_supported      (ImageView *iv,
+static gboolean     imageview_xine_is_supported      (GimvImageView *iv,
                                                       ImageInfo *info);
-static GtkWidget   *imageview_xine_create            (ImageView *iv);
-static void         imageview_xine_create_thumbnail  (ImageView *iv,
+static GtkWidget   *imageview_xine_create            (GimvImageView *iv);
+static void         imageview_xine_create_thumbnail  (GimvImageView *iv,
                                                       const gchar *type);
 
-static gboolean     imageview_xine_is_playable       (ImageView *iv,
+static gboolean     imageview_xine_is_playable       (GimvImageView *iv,
                                                       ImageInfo *info);
-static gboolean     imageview_xine_is_seekable       (ImageView *iv);
-static guint        imageview_xine_get_position      (ImageView *iv);
-static guint        imageview_xine_get_length        (ImageView *iv);
-static void         imageview_xine_play              (ImageView *iv);
-static void         imageview_xine_stop              (ImageView *iv);
-static void         imageview_xine_pause             (ImageView *iv);
-static void         imageview_xine_forward           (ImageView *iv);
-static void         imageview_xine_seek              (ImageView *iv,
+static gboolean     imageview_xine_is_seekable       (GimvImageView *iv);
+static guint        imageview_xine_get_position      (GimvImageView *iv);
+static guint        imageview_xine_get_length        (GimvImageView *iv);
+static void         imageview_xine_play              (GimvImageView *iv);
+static void         imageview_xine_stop              (GimvImageView *iv);
+static void         imageview_xine_pause             (GimvImageView *iv);
+static void         imageview_xine_forward           (GimvImageView *iv);
+static void         imageview_xine_seek              (GimvImageView *iv,
                                                       gfloat     pos);
-static void         imageview_xine_eject             (ImageView *iv);
-static ImageViewPlayableStatus
-                    imageview_xine_get_status        (ImageView *iv);
-static guint        imageview_xine_get_length        (ImageView *iv);
-static guint        imageview_xine_get_position      (ImageView *iv);
+static void         imageview_xine_eject             (GimvImageView *iv);
+static GimvImageViewPlayableStatus
+                    imageview_xine_get_status        (GimvImageView *iv);
+static guint        imageview_xine_get_length        (GimvImageView *iv);
+static guint        imageview_xine_get_position      (GimvImageView *iv);
 
 
-static ImageViewPlayableInterFace playable_if = {
+static GimvImageViewPlayableIF playable_if = {
    is_playable_fn:      imageview_xine_is_playable,
    is_seekable_fn:      imageview_xine_is_seekable,
    play_fn:             imageview_xine_play,
@@ -102,7 +102,7 @@ static ImageViewPlayableInterFace playable_if = {
 };
 
 
-static ImageViewPlugin plugin_impl[] =
+static GimvImageViewPlugin plugin_impl[] =
 {
    {
       if_version:          GIMV_IMAGE_VIEW_IF_VERSION,
@@ -281,14 +281,14 @@ gimv_xine_plugin_get_info (void)
 static gint
 idle_branched (gpointer data)
 {
-   ImageView *iv = data;
+   GimvImageView *iv = data;
    gtk_signal_emit_by_name (GTK_OBJECT(iv), "image_changed");
    return FALSE;
 }
 
 
 static void
-cb_branched (GimvXine *gtx, ImageView *iv)
+cb_branched (GimvXine *gtx, GimvImageView *iv)
 {
    GList *node;
    ImageInfo *info;
@@ -312,13 +312,13 @@ cb_branched (GimvXine *gtx, ImageView *iv)
 
 
 static void
-cb_need_next_mrl (GimvXine *gtx, gchar **next_mrl_ret, ImageView *iv)
+cb_need_next_mrl (GimvXine *gtx, gchar **next_mrl_ret, GimvImageView *iv)
 {
    GList *node, *current;
    ImageInfo *info;
    gchar *mrl;
 
-   g_return_if_fail (IS_IMAGEVIEW (iv));
+   g_return_if_fail (GIMV_IS_IMAGE_VIEW (iv));
    g_return_if_fail (next_mrl_ret);
 
    *next_mrl_ret = NULL;
@@ -349,28 +349,28 @@ cb_need_next_mrl (GimvXine *gtx, gchar **next_mrl_ret, ImageView *iv)
 
 
 static void
-cb_playback_finished (GimvXine *gtx, ImageView *iv)
+cb_playback_finished (GimvXine *gtx, GimvImageView *iv)
 {
    gboolean next;
 
-   g_return_if_fail (IS_IMAGEVIEW (iv));
+   g_return_if_fail (GIMV_IS_IMAGE_VIEW (iv));
 
    gtk_object_get (GTK_OBJECT (iv),
                    "continuance_play", &next,
                    NULL);
 
    if (next)
-      imageview_next (iv);
+      gimv_image_view_next (iv);
 
    remove_create_thumbnail_timer (iv);
    remove_movie_listener (iv);
 
-   imageview_playable_set_status (iv, ImageViewPlayableStop);
+   gimv_image_view_playable_set_status (iv, GimvImageViewPlayableStop);
 }
 
 
 static void
-cb_destroy (GtkWidget *widget, ImageView *iv)
+cb_destroy (GtkWidget *widget, GimvImageView *iv)
 {
    g_return_if_fail (iv);
 
@@ -388,25 +388,25 @@ cb_destroy (GtkWidget *widget, ImageView *iv)
 static gboolean
 timeout_movie_status_listener (gpointer data)
 {
-   ImageView   *iv = data;
+   GimvImageView   *iv = data;
    gint now, len;
    gdouble pos;
 
-   g_return_val_if_fail (IS_IMAGEVIEW (iv), FALSE);
+   g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), FALSE);
 
    g_return_val_if_fail (iv, FALSE);
 
    if (!iv->info || (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))) {
       if (movie_listener_id_table)
          g_hash_table_remove (movie_listener_id_table, iv);
-      imageview_playable_set_status (iv, ImageViewPlayableStop);
+      gimv_image_view_playable_set_status (iv, GimvImageViewPlayableStop);
       return FALSE;
    }
 
    if (!imageview_xine_is_playing (iv)) {
       if (movie_listener_id_table)
          g_hash_table_remove (movie_listener_id_table, iv);
-      imageview_playable_set_status (iv, ImageViewPlayableStop);
+      gimv_image_view_playable_set_status (iv, GimvImageViewPlayableStop);
 
       return FALSE;
    }
@@ -418,7 +418,7 @@ timeout_movie_status_listener (gpointer data)
    else
       pos = 0.0;
 
-   imageview_playable_set_position (iv, pos);
+   gimv_image_view_playable_set_position (iv, pos);
 
    return TRUE;
 }
@@ -428,14 +428,14 @@ static gint
 timeout_create_thumbnail (gpointer data)
 {
    GList *node;
-   ImageView *iv = data;
+   GimvImageView *iv = data;
 
-   g_return_val_if_fail (IS_IMAGEVIEW (iv), FALSE);
+   g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), FALSE);
 
-   node = g_list_find (imageview_get_list(), iv);
+   node = g_list_find (gimv_image_view_get_list(), iv);
    if (!node) goto ERROR;
 
-   imageview_create_thumbnail (iv);
+   gimv_image_view_create_thumbnail (iv);
 
 ERROR:
    g_hash_table_remove (create_thumbnail_id_table, iv);
@@ -444,7 +444,7 @@ ERROR:
 
 
 static void
-install_movie_listener (ImageView *iv)
+install_movie_listener (GimvImageView *iv)
 {
    guint timer;
 
@@ -456,7 +456,7 @@ install_movie_listener (ImageView *iv)
 
 
 static void
-remove_movie_listener (ImageView *iv)
+remove_movie_listener (GimvImageView *iv)
 {
    guint timer;
    gpointer data;
@@ -471,12 +471,12 @@ remove_movie_listener (ImageView *iv)
 
    g_hash_table_remove (movie_listener_id_table, iv);
 
-   imageview_playable_set_status (iv, ImageViewPlayableStop);
+   gimv_image_view_playable_set_status (iv, GimvImageViewPlayableStop);
 }
 
 
 static void
-install_create_thumbnail_timer (ImageView *iv)
+install_create_thumbnail_timer (GimvImageView *iv)
 {
    gpointer data = g_hash_table_lookup (create_thumbnail_id_table, iv);
    guint timer = GPOINTER_TO_UINT (data);
@@ -492,7 +492,7 @@ install_create_thumbnail_timer (ImageView *iv)
 
 
 static void
-remove_create_thumbnail_timer (ImageView *iv)
+remove_create_thumbnail_timer (GimvImageView *iv)
 {
    gpointer id_p;
    guint id;
@@ -506,7 +506,7 @@ remove_create_thumbnail_timer (ImageView *iv)
 
 
 static void
-imageview_xine_real_play (ImageView *iv, guint pos)
+imageview_xine_real_play (GimvImageView *iv, guint pos)
 {
    GimvXine *gtx;
    gchar *filename, *cache_file;
@@ -533,12 +533,12 @@ imageview_xine_real_play (ImageView *iv, guint pos)
    g_free (cache_file);
 
    install_movie_listener (iv);
-   imageview_playable_set_status (iv, ImageViewPlayablePlay);
+   gimv_image_view_playable_set_status (iv, GimvImageViewPlayablePlay);
 }
 
 
 static gboolean
-imageview_xine_is_playing (ImageView *iv)
+imageview_xine_is_playing (GimvImageView *iv)
 {
    GimvXine *gtx;
 
@@ -563,9 +563,9 @@ imageview_xine_is_playing (ImageView *iv)
  *
  *****************************************************************************/
 static gboolean
-imageview_xine_is_supported (ImageView *iv, ImageInfo *info)
+imageview_xine_is_supported (GimvImageView *iv, ImageInfo *info)
 {
-   g_return_val_if_fail (IS_IMAGEVIEW (iv), FALSE);
+   g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), FALSE);
    if (!info) return FALSE;
 
    return image_info_is_movie (info) || image_info_is_audio (info);
@@ -573,7 +573,7 @@ imageview_xine_is_supported (ImageView *iv, ImageInfo *info)
 
 
 static GtkWidget *
-imageview_xine_create (ImageView *iv)
+imageview_xine_create (GimvImageView *iv)
 {
    GtkWidget *gxine, *widget;
 
@@ -606,7 +606,7 @@ imageview_xine_create (ImageView *iv)
 
 
 static void
-imageview_xine_create_thumbnail (ImageView *iv, const gchar *cache_write_type)
+imageview_xine_create_thumbnail (GimvImageView *iv, const gchar *cache_write_type)
 {
    GimvImage *imcache;
    GtkWidget *gtkxine;
@@ -657,25 +657,25 @@ imageview_xine_create_thumbnail (ImageView *iv, const gchar *cache_write_type)
 
 
 static gboolean
-imageview_xine_is_playable (ImageView *iv, ImageInfo *info)
+imageview_xine_is_playable (GimvImageView *iv, ImageInfo *info)
 {
    return TRUE;
 }
 
 
 static gboolean
-imageview_xine_is_seekable (ImageView *iv)
+imageview_xine_is_seekable (GimvImageView *iv)
 {
    return TRUE;
 }
 
 
 static void
-imageview_xine_play (ImageView *iv)
+imageview_xine_play (GimvImageView *iv)
 {
    GimvXine *gtx;
 
-   g_return_if_fail (IS_IMAGEVIEW (iv));
+   g_return_if_fail (GIMV_IS_IMAGE_VIEW (iv));
 
    gtx = GIMV_XINE (GTK_BIN (iv->draw_area)->child);
    if (!GIMV_IS_XINE (gtx)) return;
@@ -684,7 +684,7 @@ imageview_xine_play (ImageView *iv)
       imageview_xine_real_play (iv, 0);
    } else if (gimv_xine_get_speed (gtx) != GIMV_XINE_SPEED_NORMAL) {
       gimv_xine_set_speed (gtx, GIMV_XINE_SPEED_NORMAL);
-      imageview_playable_set_status (iv, ImageViewPlayablePlay);
+      gimv_image_view_playable_set_status (iv, GimvImageViewPlayablePlay);
    } else {
       imageview_xine_pause (iv);
    }
@@ -692,7 +692,7 @@ imageview_xine_play (ImageView *iv)
 
 
 static void
-imageview_xine_stop (ImageView *iv)
+imageview_xine_stop (GimvImageView *iv)
 {
    GimvXine *gtx;
 
@@ -710,12 +710,12 @@ imageview_xine_stop (ImageView *iv)
 
    gimv_xine_stop (gtx);
 
-   imageview_playable_set_status (iv, ImageViewPlayableStop);
+   gimv_image_view_playable_set_status (iv, GimvImageViewPlayableStop);
 }
 
 
 static void
-imageview_xine_pause (ImageView *iv)
+imageview_xine_pause (GimvImageView *iv)
 {
    GimvXine *gtx;
 
@@ -730,12 +730,12 @@ imageview_xine_pause (ImageView *iv)
 
    gimv_xine_set_speed (gtx, GIMV_XINE_SPEED_PAUSE);
 
-   imageview_playable_set_status (iv, ImageViewPlayablePause);
+   gimv_image_view_playable_set_status (iv, GimvImageViewPlayablePause);
 }
 
 
 static void
-imageview_xine_forward (ImageView *iv)
+imageview_xine_forward (GimvImageView *iv)
 {
    GimvXine *gtx;
 
@@ -750,17 +750,17 @@ imageview_xine_forward (ImageView *iv)
 
    gimv_xine_set_speed (gtx, 12);
 
-   imageview_playable_set_status (iv, ImageViewPlayableForward);
+   gimv_image_view_playable_set_status (iv, GimvImageViewPlayableForward);
 }
 
 
 static void
-imageview_xine_seek (ImageView *iv, gfloat pos)
+imageview_xine_seek (GimvImageView *iv, gfloat pos)
 {
    GimvXine *gtx;
    gfloat ppos;
 
-   g_return_if_fail (IS_IMAGEVIEW (iv));
+   g_return_if_fail (GIMV_IS_IMAGE_VIEW (iv));
 
    gtx = GIMV_XINE (GTK_BIN (iv->draw_area)->child);
    if (!GIMV_IS_XINE (gtx)) return;
@@ -772,14 +772,14 @@ imageview_xine_seek (ImageView *iv, gfloat pos)
 
 
 static void
-imageview_xine_eject (ImageView *iv)
+imageview_xine_eject (GimvImageView *iv)
 {
    GList *plugin_list = NULL, *mrl_list = NULL;
    GimvXine *gtx;
    gchar **plugins, *str, **mrls;
    gint i, num;
 
-   g_return_if_fail (IS_IMAGEVIEW (iv));
+   g_return_if_fail (GIMV_IS_IMAGE_VIEW (iv));
 
    gtx = GIMV_XINE (GTK_BIN (iv->draw_area)->child);
    if (!GIMV_IS_XINE (gtx)) return;
@@ -820,8 +820,8 @@ imageview_xine_eject (ImageView *iv)
    }
 
    if (mrl_list) {
-      imageview_set_list_self (iv, mrl_list, mrl_list);
-      imageview_change_image (iv, mrl_list->data);
+      gimv_image_view_set_list_self (iv, mrl_list, mrl_list);
+      gimv_image_view_change_image (iv, mrl_list->data);
    } else {
       gtkutil_message_dialog (_("Error!!"), _("No available MRL found."),
                               GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (iv))));
@@ -833,35 +833,35 @@ ERROR:
 }
 
 
-static ImageViewPlayableStatus
-imageview_xine_get_status (ImageView *iv)
+static GimvImageViewPlayableStatus
+imageview_xine_get_status (GimvImageView *iv)
 {
    GimvXine *gtx;
    GimvXineSpeed speed;
 
-   g_return_val_if_fail (IS_IMAGEVIEW (iv), ImageViewPlayableStop);
+   g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), GimvImageViewPlayableStop);
 
    gtx = GIMV_XINE (GTK_BIN (iv->draw_area)->child);
-   g_return_val_if_fail (GIMV_IS_XINE (gtx), ImageViewPlayableStop);
+   g_return_val_if_fail (GIMV_IS_XINE (gtx), GimvImageViewPlayableStop);
 
    if (!imageview_xine_is_playing (iv))
-      return ImageViewPlayableStop;
+      return GimvImageViewPlayableStop;
 
    speed = gimv_xine_get_speed (gtx);
    if (speed > GIMV_XINE_SPEED_NORMAL) {
-      return ImageViewPlayableForward;
+      return GimvImageViewPlayableForward;
    } else if (speed == GIMV_XINE_SPEED_PAUSE) {
-      return ImageViewPlayablePause;
+      return GimvImageViewPlayablePause;
    } else if (speed == GIMV_XINE_SPEED_NORMAL) {
-      return ImageViewPlayablePlay;
+      return GimvImageViewPlayablePlay;
    }
 
-   return ImageViewPlayableDisable;
+   return GimvImageViewPlayableDisable;
 }
 
 
 static guint
-imageview_xine_get_position (ImageView *iv)
+imageview_xine_get_position (GimvImageView *iv)
 {
    GimvXine *gtx;
 
@@ -880,7 +880,7 @@ imageview_xine_get_position (ImageView *iv)
 
 
 static guint
-imageview_xine_get_length (ImageView *iv)
+imageview_xine_get_length (GimvImageView *iv)
 {
    GimvXine *gtx;
 
