@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: comment.c,v 1.31.2.6 2003/05/31 17:34:20 makeinu Exp $
+ * $Id: comment.c,v 1.31.2.7 2003/06/11 06:41:17 makeinu Exp $
  */
 
 /*
@@ -727,12 +727,13 @@ comment_get_from_image_info (ImageInfo *info)
 
    g_return_val_if_fail (info, NULL);
 
-   if (info->comment)
-      return comment_ref (info->comment);
+   comment = image_info_get_comment (info);
+   if (comment)
+      return comment_ref (comment);
 
    comment = comment_new ();
    comment->info = image_info_ref (info);
-   info->comment = comment;
+   image_info_set_comment (info, comment);
 
    /* get comment file path */
    image_name = image_info_get_path_with_archive (info);
@@ -1082,8 +1083,9 @@ comment_finalize (GtkObject *object)
    g_free (comment->filename);
    comment->filename = NULL;
    if (comment->info) {
-      comment->info->comment = NULL;
+      image_info_set_comment (comment->info, NULL);
       image_info_unref (comment->info);
+      comment->info = NULL;
    }
 
    node = comment->data_list;
