@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview.c,v 1.64.2.15 2003/05/15 17:48:24 makeinu Exp $
+ * $Id: dirview.c,v 1.64.2.17 2003/06/11 09:40:09 makeinu Exp $
  */
 
 /*
@@ -703,12 +703,14 @@ free_button_action_data (ButtonActionData *data)
 
 
 static gboolean
-idle_dirviewa_button_action (gpointer data)
+idle_dirview_button_action (gpointer data)
 {
    ButtonActionData *bdata = data;
    DirView *dv = bdata->dv;
    gchar *path = bdata->path, *label = bdata->label;
 
+   dv->priv->button_action_id = 0;
+
    switch (abs (bdata->action_num)) {
    case MouseActLoadThumb:
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
@@ -787,7 +789,8 @@ dirview_button_action (DirView *dv, GdkEventButton *event, gint num)
       data->label      = g_strdup (node_text);
       data->action_num = num;
 
-      gtk_idle_add (idle_dirviewa_button_action, data);
+      dv->priv->button_action_id
+         = gtk_idle_add (idle_dirview_button_action, data);
 
       return FALSE;
       break;
@@ -847,9 +850,9 @@ dirview_cancel_drag_scroll (DirView *dv)
 {
    g_return_if_fail (dv);
 
-   if (dv->priv->scroll_timer_id != -1){
+   if (dv->priv->scroll_timer_id){
       gtk_timeout_remove (dv->priv->scroll_timer_id);
-      dv->priv->scroll_timer_id = -1;
+      dv->priv->scroll_timer_id = 0;
    }
 }
 
@@ -974,6 +977,20 @@ cb_dirview_destroyed (GtkWidget *widget, DirView *dv)
 {
    g_return_if_fail (dv);
 
+   dirview_cancel_drag_scroll (dv);
+
+   if (dv->priv->button_action_id)
+      gtk_idle_remove (dv->priv->button_action_id);
+   dv->priv->button_action_id = 0;
+
+   if (dv->priv->swap_com_id)
+      gtk_idle_remove (dv->priv->swap_com_id);
+   dv->priv->swap_com_id = 0;
+
+   if (dv->priv->change_root_id)
+      gtk_idle_remove (dv->priv->change_root_id);
+   dv->priv->change_root_id = 0;
+
    gtk_widget_destroy (dv->dirtree);
 
    g_free (dv->root_dir);
@@ -2023,6 +2040,8 @@ idle_change_root (gpointer data)
 
    g_return_val_if_fail (dv, FALSE);
 
+   dv->priv->change_root_id = 0;
+
    dirview_change_root (dv, dv->root_dir);
    dirview_change_dir (dv, dv->root_dir);
    /*
@@ -2067,7 +2086,10 @@ dirview_create (const gchar *root_dir, GtkWidget *parent_win, ThumbWindow *tw)
    dv->show_toolbar      = conf.dirview_show_toolbar;
    dv->show_dotfile      = conf.dirview_show_dotfile;
    dv->priv->hilit_dir        = -1;
-   dv->priv->scroll_timer_id  = -1;
+   dv->priv->scroll_timer_id  = 0;
+   dv->priv->button_action_id = 0;
+   dv->priv->swap_com_id      = 0;
+   dv->priv->change_root_id   = 0;
 
    /* main vbox */
    dv->container = gtk_vbox_new (FALSE, 0);
@@ -2115,7 +2137,7 @@ dirview_create (const gchar *root_dir, GtkWidget *parent_win, ThumbWindow *tw)
    /* ctree */
    dirview_create_ctree (dv);
 
-   gtk_idle_add (idle_change_root, dv);
+   dv->priv->change_root_id = gtk_idle_add (idle_change_root, dv);
    /* dirview_go_home (dirtree); */
 
    return dv;
