@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview2.c,v 1.18.2.14 2003/05/15 17:48:24 makeinu Exp $
+ * $Id: dirview2.c,v 1.18.2.15 2003/06/11 06:41:18 makeinu Exp $
  */
 
 #ifndef GTK_DISABLE_DEPRECATED
@@ -160,7 +160,7 @@ static gboolean   get_iter_from_path             (DirView        *dv,
                                                   GtkTreeIter    *iter);
 static void       adjust_tree                    (GtkTreeView    *treeview,
                                                   GtkTreeIter    *iter);
-static void       adjust_tree_idle               (GtkTreeView    *treeview,
+static void       adjust_tree_idle               (DirView        *dv,
                                                   GtkTreeIter    *iter);
 static void       get_expanded_dirs              (GtkTreeView    *treeview,
                                                   GtkTreePath    *treepath,
@@ -212,6 +212,18 @@ cb_dirview_destroyed (GtkWidget *widget, DirView *dv)
 {
    g_return_if_fail (dv);
 
+   if (dv->priv->button_action_id)
+      gtk_idle_remove (dv->priv->button_action_id);
+   dv->priv->button_action_id = 0;
+
+   if (dv->priv->swap_com_id)
+      gtk_idle_remove (dv->priv->swap_com_id);
+   dv->priv->swap_com_id = 0;
+
+   if (dv->priv->adjust_tree_id)
+      gtk_idle_remove (dv->priv->adjust_tree_id);
+   dv->priv->adjust_tree_id = 0;
+
    g_free (dv->root_dir);
    g_free (dv->priv);
    g_free (dv);
@@ -1007,7 +1019,7 @@ dirview_create_treeview (DirView *dv, const gchar *root)
 
    gtk_tree_path_free (treepath);
 
-   adjust_tree_idle (GTK_TREE_VIEW (dv->dirtree), NULL);
+   adjust_tree_idle (dv, NULL);
 }
 
 
@@ -1293,6 +1305,7 @@ get_iter_from_path (DirView *dv, const gchar *str, GtkTreeIter *iter)
 
 
 struct AdjustTreeIdle {
+   DirView     *dv;
    GtkTreeView *treeview;
    GtkTreeIter *iter;
 };
@@ -1302,6 +1315,8 @@ static gint
 idle_adjust_tree (gpointer data)
 {
    struct AdjustTreeIdle *idle = data;
+
+   idle->dv->priv->adjust_tree_id = 0;
    adjust_tree (idle->treeview, idle->iter);
    g_free (idle->iter);
    g_free (idle);
@@ -1310,14 +1325,16 @@ idle_adjust_tree (gpointer data)
 
 
 static void
-adjust_tree_idle (GtkTreeView *treeview, GtkTreeIter *iter)
+adjust_tree_idle (DirView *dv, GtkTreeIter *iter)
 {
+   GtkTreeView *treeview = GTK_TREE_VIEW (dv->dirtree);
    struct AdjustTreeIdle *idle;
 
    g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
 
    idle = g_new0(struct AdjustTreeIdle, 1);
 
+   idle->dv = dv;
    idle->treeview = treeview;
    if (iter) {
       idle->iter = g_new0 (GtkTreeIter, 1);
@@ -1326,7 +1343,7 @@ adjust_tree_idle (GtkTreeView *treeview, GtkTreeIter *iter)
       idle->iter = NULL;
    }
 
-   gtk_idle_add (idle_adjust_tree, idle);
+   dv->priv->adjust_tree_id = gtk_idle_add (idle_adjust_tree, idle);
 }
 
 
@@ -1404,7 +1421,7 @@ refresh_dir_tree (DirView *dv, GtkTreeIter *parent_iter)
    /* adjust tree pos */
    selected = get_iter_from_path (dv, selected_path, &iter);
    if (selected)
-      adjust_tree_idle (GTK_TREE_VIEW (dv->dirtree), &iter);
+      adjust_tree_idle (dv, &iter);
 
    g_free (selected_path);
 }
@@ -1523,12 +1540,14 @@ free_button_action_data (ButtonActionData *data)
 
 
 static gboolean
-idle_dirviewa_button_action (gpointer data)
+idle_dirview_button_action (gpointer data)
 {
    ButtonActionData *bdata = data;
    DirView *dv = bdata->dv;
    gchar *path = bdata->path, *label = bdata->label;
 
+   dv->priv->button_action_id = 0;
+
    switch (abs (bdata->action_num)) {
    case MouseActLoadThumb:
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
@@ -1605,7 +1624,8 @@ dirview_button_action (DirView *dv, GdkEventButton *event, gint num)
       data->label      = label;
       data->action_num = num;
 
-      gtk_idle_add (idle_dirviewa_button_action, data);
+      dv->priv->button_action_id
+         = gtk_idle_add (idle_dirview_button_action, data);
 
       gtk_tree_path_free (treepath);
 
@@ -1667,7 +1687,7 @@ dirview_change_root (DirView *dv, const gchar *root_dir)
 
    gtk_tree_path_free (treepath);
 
-   adjust_tree_idle (GTK_TREE_VIEW (dv->dirtree), NULL);
+   adjust_tree_idle (dv, NULL);
 }
 
 
@@ -1716,7 +1736,7 @@ dirview_change_dir (DirView *dv, const gchar *str)
 
    if (success) {
       model = gtk_tree_view_get_model (GTK_TREE_VIEW (dv->dirtree));
-      adjust_tree_idle (GTK_TREE_VIEW (dv->dirtree), &iter);
+      adjust_tree_idle (dv, &iter);
    } else {
       dirview_change_root (dv, str);
    }
@@ -1855,8 +1875,11 @@ dirview_create (const gchar *root_dir,
    dv->show_toolbar      = conf.dirview_show_toolbar;
    dv->show_dotfile      = conf.dirview_show_dotfile;
    dv->priv->hilit_dir         = -1;
-   dv->priv->scroll_timer_id   = -1;
+   dv->priv->scroll_timer_id   = 0;
    dv->priv->drag_tree_row     = NULL;
+   dv->priv->button_action_id  = 0;
+   dv->priv->swap_com_id       = 0;
+   dv->priv->adjust_tree_id    = 0;
 
    /* main vbox */
    dv->container = gtk_vbox_new (FALSE, 0);
