@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: fileload.c,v 1.38.2.8 2003/05/15 13:58:14 makeinu Exp $
+ * $Id: fileload.c,v 1.38.2.9 2003/06/09 12:46:11 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -42,8 +42,7 @@
 #include "fileutil.h"
 #include "gimv_icon_stock.h"
 #include "image_info.h"
-#include "image_view.h"
-#include "image_window.h"
+#include "gimv_image_win.h"
 #include "thumbnail_view.h"
 #include "thumbnail_window.h"
 
@@ -339,7 +338,7 @@ open_image_files_in_image_view (FilesLoader *files)
       } else {
          ImageInfo *info = image_info_get (filename);
          if (info)
-            imagewin_open_window (info);
+            gimv_image_win_open_window (info);
       }
 
       pos = g_list_position (files->filelist, node) + 1;
@@ -1047,7 +1046,7 @@ cb_filebrowser_add_thumbnail (GtkWidget *widget, FileSel *filesel)
 static void
 cb_filebrowser_ok_sel (GtkWidget *widget, FileSel *filesel)
 {
-   ImageWindow *iw;
+   GimvImageWin *iw;
    gchar *filename;
    struct stat st;
 
@@ -1075,7 +1074,7 @@ cb_filebrowser_ok_sel (GtkWidget *widget, FileSel *filesel)
       {
          ImageInfo *info = image_info_get (filename);
          if (info)
-            iw = imagewin_open_window_auto (info);
+            iw = gimv_image_win_open_window_auto (info);
       } else {
          g_print (_("Not an image (or unsupported) file!!\n"));
       }
