@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimageview.c,v 1.37.2.5 2003/05/15 13:58:15 makeinu Exp $
+ * $Id: gimageview.c,v 1.37.2.7 2003/06/10 14:54:30 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -37,7 +37,7 @@
 #include "gfileutil.h"
 #include "gimv_image.h"
 #include "gimv_icon_stock.h"
-#include "image_window.h"
+#include "gimv_image_win.h"
 #include "prefs.h"
 #include "gimv_plugin.h"
 #include "slideshow.h"
@@ -135,7 +135,7 @@ void
 gimv_quit (void)
 {
    ThumbWindow *tw;
-   ImageWindow *iw;
+   GimvImageWin *iw;
    GList *node;
    gchar buf[MAX_PATH_LEN];
 
@@ -147,12 +147,12 @@ gimv_quit (void)
          thumbwin_store_win_state_to_config (tw);
    }
 
-   node = g_list_last (imagewin_get_list());
+   node = g_list_last (gimv_image_win_get_list());
 
    if (node) {
       iw = node->data;
       if (iw && conf.imgwin_save_win_state)
-         imagewin_store_win_state_to_config (iw);
+         gimv_image_win_save_state (iw);
    }
 
    /* save config to disk */
@@ -232,7 +232,7 @@ idle_open_image_startup (gpointer data)
             g_warning (_("If you want to scan directory, use \"-d\" option."));
       }
       /* quit if no window opened */
-      if (!thumbwin_get_list() && !imagewin_get_list()) {
+      if (!thumbwin_get_list() && !gimv_image_win_get_list()) {
          if (!conf.startup_no_warning)
             g_warning (_("No window opened!! Quiting..."));
          quit_main = TRUE;
@@ -378,7 +378,7 @@ show_splash ()
 gint
 main (gint argc, gchar *argv[])
 {
-   ImageWindow *iw = NULL;
+   GimvImageWin *iw = NULL;
    ThumbWindow *tw = NULL;
    gint remaining;
    gboolean open_thumbwin = FALSE;
@@ -402,12 +402,12 @@ main (gint argc, gchar *argv[])
       tw = thumbwin_open_window ();
    }
    if (args_val.open_imagewin) {
-      iw = imagewin_open_window (NULL);
+      iw = gimv_image_win_open_window (NULL);
    }
 
    /* set FilesLoader struct data for opening files */
    files = get_files_from_argument (argc, argv, remaining);
-   if (!files && !thumbwin_get_list() && !imagewin_get_list()) {
+   if (!files && !thumbwin_get_list() && !gimv_image_win_get_list()) {
       exit (1);
    } else if (tw && files && files->dirlist) {
       GList *list = g_list_last (files->dirlist);
