@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimageview.h,v 1.12.2.3 2003/05/15 13:58:15 makeinu Exp $
+ * $Id: gimageview.h,v 1.12.2.5 2003/06/11 06:41:19 makeinu Exp $
  */
 
 #ifndef __GIMAGEVIEW_H__
@@ -48,16 +48,17 @@
 #define MAX_PATH_LEN  1024
 
 /* type defs */
-typedef struct FilesLoader_Tag FilesLoader;
-typedef struct ImageInfo_Tag   ImageInfo;
-typedef struct ImageWindow_Tag ImageWindow;
-typedef struct ImageView_Tag   ImageView;
-typedef struct ThumbWindow_Tag ThumbWindow;
-typedef struct ThumbView_Tag   ThumbView;
-typedef struct Thumbnail_Tag   Thumbnail;
-typedef struct DirView_Tag     DirView;
-typedef struct CommentView_Tag CommentView;
-typedef struct SlideShow_Tag   SlideShow;
+typedef struct FilesLoader_Tag   FilesLoader;
+typedef struct ImageInfo_Tag     ImageInfo;
+typedef struct GimvImageWin_Tag  GimvImageWin;
+typedef struct GimvImageView_Tag GimvImageView;
+typedef struct ThumbWindow_Tag   ThumbWindow;
+typedef struct ThumbView_Tag     ThumbView;
+typedef struct Thumbnail_Tag     Thumbnail;
+typedef struct DirView_Tag       DirView;
+typedef struct Comment_Tag       Comment;
+typedef struct CommentView_Tag   CommentView;
+typedef struct SlideShow_Tag     SlideShow;
 
 /* will be replaced to GimvVFS */
 typedef struct _FRArchive       FRArchive;
