@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gtkutils.c,v 1.22.2.7 2003/06/02 12:38:28 makeinu Exp $
+ * $Id: gtkutils.c,v 1.22.2.8 2003/06/09 12:46:11 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -343,7 +343,7 @@ gtkutil_confirm_dialog (const gchar *title, const gchar *message,
 }
 
 
-#include "image_view.h"
+#include "gimv_image_view.h"
 
 typedef struct OverWriteDialog_Tag
 {
@@ -358,15 +358,15 @@ typedef struct OverWriteDialog_Tag
 static void
 cb_show_compare (GtkButton *button, OverWriteDialog *dialog)
 {
-   imageview_change_image (IMAGEVIEW (dialog->iv1), dialog->info1);
-   imageview_change_image (IMAGEVIEW (dialog->iv2), dialog->info2);
+   gimv_image_view_change_image (GIMV_IMAGE_VIEW (dialog->iv1), dialog->info1);
+   gimv_image_view_change_image (GIMV_IMAGE_VIEW (dialog->iv2), dialog->info2);
 }
 
 
 static void
 cb_show_image1 (GtkButton *button, OverWriteDialog *dialog)
 {
-   imageview_change_image (IMAGEVIEW (dialog->iv1), dialog->info1);
+   gimv_image_view_change_image (GIMV_IMAGE_VIEW (dialog->iv1), dialog->info1);
 }
 
 
@@ -374,7 +374,7 @@ cb_show_image1 (GtkButton *button, OverWriteDialog *dialog)
 static void
 cb_show_image2 (GtkButton *button, OverWriteDialog *dialog)
 {
-   imageview_change_image (IMAGEVIEW (dialog->iv2), dialog->info2);
+   gimv_image_view_change_image (GIMV_IMAGE_VIEW (dialog->iv2), dialog->info2);
 }
 
 
@@ -529,17 +529,17 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
       gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 2);
       gtk_widget_show (vbox2);
 
-      dialog.iv1 = imageview_new (NULL);
+      dialog.iv1 = gimv_image_view_new (NULL);
       gtk_object_set (GTK_OBJECT (dialog.iv1),
                       "fit_when_change", TRUE,
                       "keep_aspect",     TRUE,
                       NULL);
-      imageview_hide_scrollbar (IMAGEVIEW (dialog.iv1));
+      gimv_image_view_hide_scrollbar (GIMV_IMAGE_VIEW (dialog.iv1));
       gtk_widget_set_usize (dialog.iv1, -1, 150);
       gtk_box_pack_start (GTK_BOX (vbox2), dialog.iv1, TRUE, TRUE, 0);
       gtk_widget_show (dialog.iv1);
 
-      /* imageview_set_text (dialog.iv1, information) */
+      /* gimv_image_view_set_text (dialog.iv1, information) */
 
 
       /* source */
@@ -547,17 +547,17 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
       gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 2);
       gtk_widget_show (vbox2);
 
-      dialog.iv2 = imageview_new (NULL);
+      dialog.iv2 = gimv_image_view_new (NULL);
       gtk_object_set (GTK_OBJECT (dialog.iv2),
                       "fit_when_change", TRUE,
                       "keep_aspect",     TRUE,
                       NULL);
-      imageview_hide_scrollbar (IMAGEVIEW (dialog.iv2));
+      gimv_image_view_hide_scrollbar (GIMV_IMAGE_VIEW (dialog.iv2));
       gtk_widget_set_usize (dialog.iv2, -1, 150);
       gtk_box_pack_start (GTK_BOX (vbox2), dialog.iv2, TRUE, TRUE, 0);
       gtk_widget_show (dialog.iv2);
 
-      /* imageview_set_text (dialog.iv2, information) */
+      /* gimv_image_view_set_text (dialog.iv2, information) */
    }
 
    vbox = gtk_vbox_new (FALSE, 0);
