@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_info.c,v 1.43.2.10 2003/05/31 17:34:21 makeinu Exp $
+ * $Id: image_info.c,v 1.43.2.11 2003/06/11 06:41:19 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -28,17 +28,22 @@
 
 #include "gimageview.h"
 
+#include "comment.h"
 #include "gfileutil.h"
 #include "gimv_image.h"
 #include "gimv_mime_types.h"
 #include "fileutil.h"
+#include "fr-archive.h"
 #include "image_info.h"
 #include "prefs.h"
 #include "thumbnail.h"
 #include "thumbnail_support.h"
 
 
-GHashTable *ImageInfoTable = NULL;
+static GHashTable *image_info_table = NULL;
+static GHashTable *comment_table    = NULL;
+static GHashTable *archive_table    = NULL;
+static GHashTable *link_table       = NULL;
 
 
 /******************************************************************************
@@ -55,14 +60,10 @@ image_info_new (const gchar *filename)
    g_return_val_if_fail (info, NULL);
 
    info->filename     = g_strdup (filename);
-   info->archive_name = NULL;
-   info->archive      = NULL;
-   info->link         = NULL;
    info->format       = gimv_image_detect_type_by_ext (filename);
    info->width        = -1;
    info->height       = -1;
    info->depth        = -1;
-   info->comment      = NULL;
    info->flags        = 0;
 
    info->ref_count = 1;
@@ -92,17 +93,17 @@ image_info_get (const gchar *filename)
 
    g_return_val_if_fail (filename, NULL);
 
-   if (!ImageInfoTable) {
-      ImageInfoTable = g_hash_table_new (g_str_hash, g_str_equal);
+   if (!image_info_table) {
+      image_info_table = g_hash_table_new (g_str_hash, g_str_equal);
    }
 
-   info = g_hash_table_lookup (ImageInfoTable, filename);
+   info = g_hash_table_lookup (image_info_table, filename);
    if (!info) {
       if (!file_exists (filename)) return NULL;
       info = image_info_new (filename);
       if (!info) return NULL;
       stat (filename, &info->st);
-      g_hash_table_insert (ImageInfoTable, info->filename, info);
+      g_hash_table_insert (image_info_table, info->filename, info);
    } else {
       if (stat (filename, &st)) return NULL;
       if (info->st.st_size != st.st_size
@@ -136,16 +137,16 @@ image_info_get_url (const gchar *url)
 
    g_return_val_if_fail (url, NULL);
 
-   if (!ImageInfoTable) {
-      ImageInfoTable = g_hash_table_new (g_str_hash, g_str_equal);
+   if (!image_info_table) {
+      image_info_table = g_hash_table_new (g_str_hash, g_str_equal);
    }
 
-   info = g_hash_table_lookup (ImageInfoTable, url);
+   info = g_hash_table_lookup (image_info_table, url);
    if (!info) {
       info = image_info_new (url);
       if (!info) return NULL;
       info->flags |= IMAGE_INFO_URL_FLAG;
-      g_hash_table_insert (ImageInfoTable, info->filename, info);
+      g_hash_table_insert (image_info_table, info->filename, info);
    } else {
       image_info_ref (info);
    }
@@ -165,20 +166,21 @@ image_info_get_with_archive (const gchar *filename,
    g_return_val_if_fail (filename, NULL);
    g_return_val_if_fail (archive, NULL);
 
-   if (!ImageInfoTable) {
-      ImageInfoTable = g_hash_table_new (g_str_hash, g_str_equal);
-   }
+   if (!image_info_table)
+      image_info_table = g_hash_table_new (g_str_hash, g_str_equal);
+
+   if (!archive_table)
+      archive_table = g_hash_table_new (g_direct_hash, g_direct_equal);
 
    g_snprintf (buf, MAX_PATH_LEN, "%s/%s", archive->filename, filename);
 
-   info = g_hash_table_lookup (ImageInfoTable, buf);
+   info = g_hash_table_lookup (image_info_table, buf);
    if (!info) {
       info = image_info_new (filename);
-      info->archive_name = g_strdup (archive->filename);
-      info->archive = archive;
-      g_hash_table_insert (ImageInfoTable, g_strdup (buf), info);
+      g_hash_table_insert (image_info_table, g_strdup (buf), info);
+      g_hash_table_insert (archive_table, info, archive);
    } else {
-      /* FIXME!! update if necessary */
+      /* FIXME!! update if needed */
       /* image_info_ref (info); */
    }
 
@@ -196,7 +198,7 @@ image_info_lookup (const gchar *filename)
 {
    ImageInfo *info;
 
-   info = g_hash_table_lookup (ImageInfoTable, filename);
+   info = g_hash_table_lookup (image_info_table, filename);
 
    if (info)
       image_info_ref (info);
@@ -214,46 +216,42 @@ image_info_finalize (ImageInfo *info)
    g_return_if_fail (info);
 
    /* remove data from hash table */
-   if (info->archive) {
+   if (info->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG) {
       gchar *orig_key;
       ImageInfo *value;
-      gboolean success;
+      gboolean success = FALSE;
+      FRArchive *archive = g_hash_table_lookup (archive_table, info);
 
-      g_snprintf (buf, MAX_PATH_LEN, "%s/%s",
-                  info->archive->filename, info->filename);
-      success = g_hash_table_lookup_extended (ImageInfoTable, buf,
-                                              (gpointer) &orig_key,
-                                              (gpointer) &value);
+      if (archive) {
+         g_snprintf (buf, MAX_PATH_LEN, "%s/%s",
+                     archive->filename, info->filename);
+         success = g_hash_table_lookup_extended (image_info_table, buf,
+                                                 (gpointer) &orig_key,
+                                                 (gpointer) &value);
+         g_hash_table_remove (archive_table, info);
+      }
       if (success) {
-         g_hash_table_remove (ImageInfoTable, buf);
+         g_hash_table_remove (image_info_table, buf);
          g_free (orig_key);
       }
    } else {
-      g_hash_table_remove (ImageInfoTable, info->filename);
+      g_hash_table_remove (image_info_table, info->filename);
    }
 
+   image_info_set_comment (info, NULL);
+   image_info_set_link (info, NULL);
+
    if (info->filename) {
       g_free (info->filename);
       info->filename = NULL;
    }
-   if (info->archive_name) {
-      g_free (info->archive_name);
-      info->archive_name = NULL;
-   }
-   if (info->link) {
-      g_free (info->link);
-      info->link = NULL;;
-   }
-   if (info->archive) {
-      info->archive = NULL;
-   }
    g_free (info);
 
    /* destroy hash table if needed */
-   num = g_hash_table_size (ImageInfoTable);
+   num = g_hash_table_size (image_info_table);
    if (num < 1) {
-      g_hash_table_destroy (ImageInfoTable);
-      ImageInfoTable = NULL;
+      g_hash_table_destroy (image_info_table);
+      image_info_table = NULL;
    }
 }
 
@@ -265,8 +263,10 @@ image_info_ref (ImageInfo *info)
 
    info->ref_count++;
 
-   if (info->archive) {
-      fr_archive_ref (FR_ARCHIVE (info->archive));
+   if (info->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG) {
+      FRArchive *archive = g_hash_table_lookup (archive_table, info);
+      if (archive)
+         fr_archive_ref (archive);
    }
 
    return info;
@@ -276,11 +276,12 @@ image_info_ref (ImageInfo *info)
 void
 image_info_unref (ImageInfo *info)
 {
-   FRArchive *archive;
+   FRArchive *archive = NULL;
 
    g_return_if_fail (info);
 
-   archive = info->archive;
+   if (info->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG)
+      archive = g_hash_table_lookup (archive_table, info);
 
    info->ref_count--;
 
@@ -318,6 +319,69 @@ image_info_set_size (ImageInfo *info, gint width, gint height)
    info->height = height;
 }
 
+void
+image_info_set_comment (ImageInfo *info, Comment *comment)
+{
+   Comment *prev;
+
+   g_return_if_fail (info);
+
+   if (!comment_table)
+      comment_table = g_hash_table_new (g_direct_hash, g_direct_equal);
+
+   prev = g_hash_table_lookup (comment_table, info);
+   if (prev) {
+      g_hash_table_remove (comment_table, info);
+      /* comment_unref (prev); */
+   }
+
+   if (comment) {
+      comment_ref (comment);
+      g_hash_table_insert (comment_table, info, comment);
+   }
+}
+
+
+Comment *
+image_info_get_comment (ImageInfo *info)
+{
+   g_return_val_if_fail (info, NULL);
+
+   if (!comment_table) return NULL;
+   return g_hash_table_lookup (comment_table, info);
+}
+
+
+void
+image_info_set_link (ImageInfo *info, const gchar *link)
+{
+   gchar *old_link;
+
+   g_return_if_fail (info);
+
+   if (!link_table)
+      link_table = g_hash_table_new (g_direct_hash, g_direct_equal);
+
+   old_link = g_hash_table_lookup (link_table, info);
+   if (old_link) {
+      g_hash_table_remove (link_table, info);
+      g_free (old_link);
+   }
+
+   if (link && *link)
+      g_hash_table_insert (link_table, info, g_strdup (link));
+}
+
+
+FRArchive *
+image_info_get_archive (ImageInfo *info)
+{
+   g_return_val_if_fail (info, NULL);
+
+   if (!archive_table) return NULL;
+   return g_hash_table_lookup (archive_table, info);
+}
+
 
 void
 image_info_set_flags (ImageInfo *info, ImageInfoFlags flags)
@@ -401,7 +465,7 @@ image_info_is_in_archive (ImageInfo *info)
 {
    g_return_val_if_fail (info, FALSE);
 
-   if (info->archive_name)
+   if (info->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG)
       return TRUE;
    else
       return FALSE;
@@ -481,6 +545,8 @@ image_info_is_audio (ImageInfo *info)
 gboolean
 image_info_is_same (ImageInfo *info1, ImageInfo *info2)
 {
+   FRArchive *arc1 = NULL, *arc2 = NULL;
+
    g_return_val_if_fail (info1, FALSE);
    g_return_val_if_fail (info2, FALSE);
    g_return_val_if_fail (info1->filename && *info1->filename, FALSE);
@@ -489,12 +555,20 @@ image_info_is_same (ImageInfo *info1, ImageInfo *info2)
    if (strcmp (info1->filename, info2->filename))
       return FALSE;
 
-   if (!info1->archive && !info2->archive)
+   if (!(info1->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG)
+       && !(info2->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG))
+   {
       return TRUE;
+   }
 
-   if (info1->archive_name && *info2->archive_name
-       && info2->archive_name && *info2->archive_name
-       && !strcmp (info1->archive_name, info2->archive_name))
+   if (archive_table) {
+      arc1 = g_hash_table_lookup (archive_table, info1);
+      arc2 = g_hash_table_lookup (archive_table, info2);
+   }
+
+   if (arc1 && arc1->filename && *arc1->filename
+       && arc2 && arc2->filename && *arc2->filename
+       && !strcmp (arc1->filename, arc2->filename))
    {
       return TRUE;
    }
@@ -515,22 +589,31 @@ image_info_get_path (ImageInfo *info)
 gchar *
 image_info_get_path_with_archive (ImageInfo *info)
 {
+   FRArchive *arc;
+
    g_return_val_if_fail (info, NULL);
 
-   if (!info->archive)
+   if (!(info->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG))
       return g_strdup (info->filename);
 
-   return g_strconcat (info->archive_name, "/", info->filename, NULL);
+   arc = g_hash_table_lookup (archive_table, info);
+   g_return_val_if_fail (arc, NULL);
+
+   return g_strconcat (arc->filename, "/", info->filename, NULL);
 }
 
 
 const gchar *
 image_info_get_archive_path (ImageInfo *info)
 {
-   g_return_val_if_fail (info, NULL);
-   g_return_val_if_fail (info->archive, NULL);
+   FRArchive *arc;
 
-   return info->archive->filename;
+   g_return_val_if_fail (info, NULL);
+   g_return_val_if_fail (info->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG, NULL);
+
+   arc = g_hash_table_lookup (archive_table, info);
+
+   return arc->filename;
 }
 
 
@@ -554,8 +637,9 @@ image_info_get_temp_file_path (ImageInfo *info)
    gchar *filename, buf[MAX_PATH_LEN];
 
    g_return_val_if_fail (info, NULL);
+   g_return_val_if_fail (archive_table, FALSE);
 
-   archive = info->archive;
+   archive = g_hash_table_lookup (archive_table, info);
    g_return_val_if_fail (archive, NULL);
 
    filename = info->filename;
@@ -620,8 +704,9 @@ image_info_extract_archive (ImageInfo *info)
    gchar *filename, *temp_file, buf[MAX_PATH_LEN];
 
    g_return_val_if_fail (info, FALSE);
+   g_return_val_if_fail (archive_table, FALSE);
 
-   archive = info->archive;
+   archive = g_hash_table_lookup (archive_table, info);
    g_return_val_if_fail (archive, FALSE);
 
    filename = info->filename;
@@ -715,7 +800,7 @@ image_info_rename_image (ImageInfo *info, const gchar *filename)
 
    g_return_val_if_fail (info, FALSE);
    g_return_val_if_fail (info->filename, FALSE);
-   g_return_val_if_fail (!info->archive, FALSE);
+   g_return_val_if_fail (!(info->flags & IMAGE_INFO_ARCHIVE_MEMBER_FLAG), FALSE);
    g_return_val_if_fail (filename, FALSE);
 
    /* rename the file */
