@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_info.h,v 1.26.2.5 2003/05/17 17:43:27 makeinu Exp $
+ * $Id: image_info.h,v 1.26.2.6 2003/06/11 06:41:19 makeinu Exp $
  */
 
 #ifndef __IMAGE_INFO_H__
@@ -28,7 +28,6 @@
 #include <unistd.h>
 
 #include "gimageview.h"
-#include "comment.h"
 #include "gimv_io.h"
 
 
@@ -50,12 +49,6 @@ struct ImageInfo_Tag
 {
    gchar          *filename;   /* If the file is a member of a archive,
                                   this value sholud be set as relative path. */
-   gchar          *archive_name;
-   FRArchive      *archive;    /* If the file is a normal file,
-                                  this value should be set to NULL.
-                                  If it is a member of archive,
-                                  should be set to the FRArchive struct */
-   gchar          *link;       /* for tar archive  */
    const gchar    *format;
    struct stat     st;
 
@@ -64,8 +57,6 @@ struct ImageInfo_Tag
    gint            depth;
    /* ColorSpace   color_space; */
 
-   Comment        *comment;    /* 1:1 relation */
-
    ImageInfoFlags  flags;
 
    /* reference count */
@@ -89,10 +80,16 @@ ImageInfo      *image_info_get_url              (const gchar   *url);
  */
 ImageInfo      *image_info_lookup               (const gchar   *filename);
 
-/* setter */
+/* setter/getter */
 void            image_info_set_size             (ImageInfo     *info,
                                                  gint           width,
                                                  gint           height);
+void            image_info_set_comment          (ImageInfo     *info,
+                                                 Comment       *comment);
+Comment        *image_info_get_comment          (ImageInfo     *info);
+void            image_info_set_link             (ImageInfo     *info,
+                                                 const gchar   *link);
+FRArchive      *image_info_get_archive          (ImageInfo     *info);
 void            image_info_set_flags            (ImageInfo     *info,
                                                  ImageInfoFlags flags);
 void            image_info_unset_flags          (ImageInfo     *info,
