@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs.c,v 1.71.2.15 2003/06/03 12:35:20 makeinu Exp $
+ * $Id: prefs.c,v 1.71.2.16 2003/06/09 12:46:12 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -29,7 +29,7 @@
 #include "gimageview.h"
 
 #include "gimv_icon_stock.h"
-#include "image_window.h"
+#include "gimv_image_win.h"
 #include "prefs.h"
 #include "gimv_plugin.h"
 #include "thumbnail_window.h"
