@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_thumbwin.c,v 1.3.2.8 2003/06/03 12:35:21 makeinu Exp $
+ * $Id: prefs_ui_thumbwin.c,v 1.3.2.9 2003/06/09 12:46:13 makeinu Exp $
  */
 
 #include <string.h>
@@ -518,7 +518,7 @@ prefs_thumbwin_page (void)
    gtk_box_pack_start (GTK_BOX (hbox3), radio[0], FALSE, FALSE, 0);
    gtk_signal_connect (GTK_OBJECT (radio[0]), "toggled",
                        GTK_SIGNAL_FUNC (cb_player_visible),
-                       GINT_TO_POINTER(ImageViewPlayerVisibleShow));
+                       GINT_TO_POINTER(GimvImageViewPlayerVisibleShow));
    prefs_win.thumbwin_player_radio[0] = radio[0];
 
    radio[1] = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio[0]),
@@ -526,7 +526,7 @@ prefs_thumbwin_page (void)
    gtk_box_pack_start (GTK_BOX (hbox3), radio[1], FALSE, FALSE, 0);
    gtk_signal_connect (GTK_OBJECT (radio[1]), "toggled",
                        GTK_SIGNAL_FUNC (cb_player_visible),
-                       GINT_TO_POINTER(ImageViewPlayerVisibleHide));
+                       GINT_TO_POINTER(GimvImageViewPlayerVisibleHide));
    prefs_win.thumbwin_player_radio[1] = radio[1];
 
    radio[2] = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio[1]),
@@ -534,17 +534,17 @@ prefs_thumbwin_page (void)
    gtk_box_pack_start (GTK_BOX (hbox3), radio[2], FALSE, FALSE, 0);
    gtk_signal_connect (GTK_OBJECT (radio[2]), "toggled",
                        GTK_SIGNAL_FUNC (cb_player_visible),
-                       GINT_TO_POINTER(ImageViewPlayerVisibleAuto));
+                       GINT_TO_POINTER(GimvImageViewPlayerVisibleAuto));
    prefs_win.thumbwin_player_radio[2] = radio[2];
 
    switch (config_changed->preview_player_visible) {
-   case ImageViewPlayerVisibleShow:
+   case GimvImageViewPlayerVisibleShow:
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio[0]), TRUE);
       break;
-   case ImageViewPlayerVisibleHide:
+   case GimvImageViewPlayerVisibleHide:
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio[1]), TRUE);
       break;
-   case ImageViewPlayerVisibleAuto:
+   case GimvImageViewPlayerVisibleAuto:
    default:
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio[2]), TRUE);
       break;
