@@ -18,26 +18,26 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: slideshow.c,v 1.19.2.6 2003/06/02 12:38:29 makeinu Exp $
+ * $Id: slideshow.c,v 1.19.2.8 2003/06/10 14:54:33 makeinu Exp $
  */
 
 #include "gimageview.h"
 
-#include "image_window.h"
+#include "gimv_image_win.h"
 #include "prefs.h"
 #include "slideshow.h"
 
 
 gint            idle_slideshow_delete (gpointer   data);
-static GList   *next_image            (ImageView *iv,
+static GList   *next_image            (GimvImageView *iv,
                                        gpointer   list_owner,
                                        GList     *current,
                                        gpointer   data);
-static GList   *prev_image            (ImageView *iv,
+static GList   *prev_image            (GimvImageView *iv,
                                        gpointer   list_owner,
                                        GList     *current,
                                        gpointer   data);
-static void     remove_list           (ImageView *iv,
+static void     remove_list           (GimvImageView *iv,
                                        gpointer   list_owner,
                                        gpointer   data);
 
@@ -60,9 +60,9 @@ idle_slideshow_delete (gpointer data)
 
 typedef struct ChangeImageData_Tag
 {
-   SlideShow   *slideshow;
-   ImageWindow *iw;
-   ImageInfo   *info;
+   SlideShow    *slideshow;
+   GimvImageWin *iw;
+   ImageInfo    *info;
 } ChangeImageData;
 
 
@@ -71,19 +71,19 @@ change_image_idle (gpointer user_data)
 {
    ChangeImageData *data = user_data;
 
-   imagewin_change_image (data->iw, data->info);
+   gimv_image_win_change_image (data->iw, data->info);
 
    return FALSE;
 }
 
 
 static GList *
-next_image (ImageView *iv,
+next_image (GimvImageView *iv,
             gpointer list_owner,
             GList *current,
             gpointer data)
 {
-   ImageWindow *iw = data;
+   GimvImageWin *iw = data;
    GList *next, *node;
    SlideShow *slideshow = list_owner;
 
@@ -119,12 +119,12 @@ next_image (ImageView *iv,
 
 
 static GList *
-prev_image (ImageView *iv,
+prev_image (GimvImageView *iv,
             gpointer list_owner,
             GList *current,
             gpointer data)
 {
-   ImageWindow *iw = data;
+   GimvImageWin *iw = data;
    GList *prev, *node;
    SlideShow *slideshow = list_owner;
 
@@ -160,13 +160,13 @@ prev_image (ImageView *iv,
 
 
 static GList *
-nth_image (ImageView *iv,
+nth_image (GimvImageView *iv,
            gpointer list_owner,
            GList *list,
            guint nth,
            gpointer data)
 {
-   ImageWindow *iw = data;
+   GimvImageWin *iw = data;
    GList *node;
    SlideShow *slideshow = list_owner;
    ChangeImageData *change_data;
@@ -192,7 +192,7 @@ nth_image (ImageView *iv,
 
 
 static void
-remove_list (ImageView *iv, gpointer list_owner, gpointer data)
+remove_list (GimvImageView *iv, gpointer list_owner, gpointer data)
 {
    SlideShow *slideshow = list_owner;
 
@@ -228,8 +228,8 @@ slideshow_new (void)
 void
 slideshow_delete (SlideShow *slideshow)
 {
-   ImageWindow *iw;
-   ImageView *iv;
+   GimvImageWin *iw;
+   GimvImageView *iv;
 
    g_return_if_fail (slideshow);
 
@@ -259,11 +259,11 @@ slideshow_new_with_filelist (GList *filelist, GList *start)
 }
 
 
-ImageWindow *
+GimvImageWin *
 slideshow_open_window (SlideShow *slideshow)
 {
-   ImageWindow *iw;
-   ImageView *iv;
+   GimvImageWin *iw;
+   GimvImageView *iv;
    GList *current;
 
    g_return_val_if_fail (slideshow, NULL);
@@ -277,7 +277,7 @@ slideshow_open_window (SlideShow *slideshow)
                                 : slideshow->filelist;
    g_return_val_if_fail (slideshow, NULL);
 
-   slideshow->iw = imagewin_initialize (current->data);
+   slideshow->iw = GIMV_IMAGE_WIN (gimv_image_win_new (current->data));
    g_return_val_if_fail (slideshow->iw, NULL);
 
    iw = slideshow->iw;
@@ -288,52 +288,48 @@ slideshow_open_window (SlideShow *slideshow)
                   "x_scale",         conf.slideshow_img_scale,
                   "y_scale",         conf.slideshow_img_scale,
                   "fit_when_change", conf.slideshow_fit_to_win,
-                  "keep_aspect",     conf.slideshow_img_scale,
+                  "keep_aspect",     conf.slideshow_keep_aspect,
                   NULL);
 
-   if (conf.slideshow_menubar)
-      iw->flags |= ImgWinShowMenuBarFlag;
-   if (conf.slideshow_toolbar)
-      iw->flags |= ImgWinShowToolBarFlag;
-   if (conf.slideshow_player)
-      iw->flags |= ImgWinShowPlayerFlag;
-   if (conf.slideshow_statusbar)
-      iw->flags |= ImgWinShowStatusBarFlag;
+   gimv_image_win_show_menubar   (iw, conf.slideshow_menubar);
+   gimv_image_win_show_toolbar   (iw, conf.slideshow_toolbar);
+   gimv_image_win_show_player    (iw, conf.slideshow_player);
+   gimv_image_win_show_statusbar (iw, conf.slideshow_statusbar);
    switch (conf.slideshow_screen_mode) {
    case SlideShowWinModeFullScreen:
-      iw->flags |= ImgWinFullScreenFlag;
+      gimv_image_win_set_fullscreen (iw, TRUE);
       break;
    case SlideShowWinModeMaximize:
-      iw->flags |= ImgWinMaximizeFlag;
+      gimv_image_win_set_maximize (iw, TRUE);
       break;
    default:
       break;
    }
-   iw->flags            |= ImgWinHideFrameFlag;
-   iw->slideshow        = slideshow;
+   /* iw->flags |= GimvImageWinHideFrameFlag; */
+   iw->slideshow = slideshow;
 
-   imagewin_slideshow_set_repeat (iw, conf.slideshow_repeat);
-   imagewin_slideshow_set_interval (iw, conf.slideshow_interval * 1000);
+   gimv_image_win_slideshow_set_repeat (iw, conf.slideshow_repeat);
+   gimv_image_win_slideshow_set_interval (iw, conf.slideshow_interval * 1000);
 
    /* set bg color */
    if (conf.slideshow_set_bg) {
-      imageview_set_bg_color (iv,
-                              conf.slideshow_bg_color[0],
-                              conf.slideshow_bg_color[1],
-                              conf.slideshow_bg_color[2]);
+      gimv_image_view_set_bg_color (iv,
+                                    conf.slideshow_bg_color[0],
+                                    conf.slideshow_bg_color[1],
+                                    conf.slideshow_bg_color[2]);
    }
 
-   imagewin_create_window (slideshow->iw);
+   gimv_image_view_set_list (iv,
+                             slideshow->filelist,
+                             current,
+                             (gpointer) slideshow,
+                             next_image,
+                             prev_image,
+                             nth_image,
+                             remove_list,
+                             iw);
 
-   imageview_set_list (iv,
-                       slideshow->filelist,
-                       current,
-                       (gpointer) slideshow,
-                       next_image,
-                       prev_image,
-                       nth_image,
-                       remove_list,
-                       iw);
+   gtk_widget_show (GTK_WIDGET (slideshow->iw));
 
    return iw;
 }
@@ -348,7 +344,7 @@ slideshow_open_window (SlideShow *slideshow)
 void
 slideshow_play (SlideShow *slideshow)
 {
-   ImageWindow *iw = NULL;
+   GimvImageWin *iw = NULL;
 
    g_return_if_fail (slideshow);
 
@@ -359,33 +355,33 @@ slideshow_play (SlideShow *slideshow)
 
    g_return_if_fail (iw);
 
-   imagewin_slideshow_play (iw);
+   gimv_image_win_slideshow_play (iw);
 }
 
 
 void
 slideshow_stop (SlideShow *slideshow)
 {
-   ImageWindow *iw;
+   GimvImageWin *iw;
 
    g_return_if_fail (slideshow);
 
    iw = slideshow->iw;
    g_return_if_fail (iw);
 
-   imagewin_slideshow_stop (iw);
+   gimv_image_win_slideshow_stop (iw);
 }
 
 
 void
 slideshow_set_interval (SlideShow *slideshow, guint interval)
 {
-   ImageWindow *iw;
+   GimvImageWin *iw;
 
    g_return_if_fail (slideshow);
 
    iw = slideshow->iw;
    g_return_if_fail (iw);
 
-   imagewin_slideshow_set_interval (slideshow->iw, interval);
+   gimv_image_win_slideshow_set_interval (slideshow->iw, interval);
 }
