@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: thumbnail.c,v 1.32.2.8 2003/05/18 15:10:37 makeinu Exp $
+ * $Id: thumbnail.c,v 1.32.2.9 2003/06/11 06:41:19 makeinu Exp $
  */
 
 #include <string.h>
@@ -357,7 +357,6 @@ thumbnail_new (ImageInfo *info)
    thumb->mode_data = g_hash_table_new (g_str_hash, g_str_equal);
    thumb->ref_count = 0;
 
-   thumb->image          = NULL;
    thumb->thumbnail      = NULL;
    thumb->thumbnail_mask = NULL;
    thumb->icon           = NULL;
@@ -400,11 +399,6 @@ thumbnail_finalize (Thumbnail *thumb)
    /* image_info_remove_thumbnail (thumb->info, thumb); */
 
    /* free thumbnail */
-   if (thumb->image) {
-      gimv_image_unref (thumb->image);
-      thumb->image = NULL;
-   }
-
    if (thumb->thumbnail) {
       gdk_pixmap_unref (thumb->thumbnail);
       thumb->thumbnail = NULL;
