@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: thumbnail_window.h,v 1.24.2.8 2003/05/21 18:17:35 makeinu Exp $
+ * $Id: thumbnail_window.h,v 1.24.2.9 2003/06/09 12:46:13 makeinu Exp $
  */
 
 #ifndef __THUMBNAIL_WINDOW_H__
@@ -26,7 +26,7 @@
 
 #include "gimageview.h"
 
-#include "image_view.h"
+#include "gimv_image_view.h"
 #include "thumbnail_view.h"
 
 #define MIN_THUMB_SIZE 4
@@ -103,7 +103,7 @@ struct ThumbWindow_Tag
    DirView   *dv;
 
    /* image view module */
-   ImageView *iv;
+   GimvImageView *iv;
 
    /* commnet view module */
    CommentView *cv;
@@ -191,7 +191,7 @@ struct ThumbWindow_Tag
    gint       pane_size1;
    gint       pane_size2;
    gchar     *thumb_disp_mode;
-   ImageViewPlayerVisibleType player_visible;
+   GimvImageViewPlayerVisibleType player_visible;
    SortItem   sortitem;
    SortFlag   sortflags;
    gint       layout_type;
